pub struct JsObject { /* private fields */ }Expand description
Builder for JavaScript/TypeScript object literals.
Implementations
Sourceimpl JsObject
impl JsObject
pub fn new() -> Self
Sourcepub fn string(self, key: impl Into<String>, value: impl Into<String>) -> Self
pub fn string(self, key: impl Into<String>, value: impl Into<String>) -> Self
Add a property with a string value (will be quoted).
Sourcepub fn raw(self, key: impl Into<String>, value: impl Into<String>) -> Self
pub fn raw(self, key: impl Into<String>, value: impl Into<String>) -> Self
Add a property with a raw expression value (will not be quoted).
Sourcepub fn object(self, key: impl Into<String>, value: JsObject) -> Self
pub fn object(self, key: impl Into<String>, value: JsObject) -> Self
Add a property with a nested object value.
Sourcepub fn arrow_fn(self, key: impl Into<String>, value: ArrowFn) -> Self
pub fn arrow_fn(self, key: impl Into<String>, value: ArrowFn) -> Self
Add an arrow function property.
Sourcepub fn shorthand(self, name: impl Into<String>) -> Self
pub fn shorthand(self, name: impl Into<String>) -> Self
Add a shorthand property where key equals the variable name.
Sourcepub fn string_if(
self,
condition: bool,
key: impl Into<String>,
value: impl Into<String>,
) -> Self
pub fn string_if( self, condition: bool, key: impl Into<String>, value: impl Into<String>, ) -> Self
Conditionally add a string property.
Sourcepub fn string_opt(
self,
key: impl Into<String>,
value: Option<impl Into<String>>,
) -> Self
pub fn string_opt( self, key: impl Into<String>, value: Option<impl Into<String>>, ) -> Self
Conditionally add a string property using an Option.
Sourcepub fn raw_if(
self,
condition: bool,
key: impl Into<String>,
value: impl Into<String>,
) -> Self
pub fn raw_if( self, condition: bool, key: impl Into<String>, value: impl Into<String>, ) -> Self
Conditionally add a raw property.
Sourcepub fn object_if(
self,
condition: bool,
key: impl Into<String>,
value: JsObject,
) -> Self
pub fn object_if( self, condition: bool, key: impl Into<String>, value: JsObject, ) -> Self
Conditionally add a nested object property.
Sourcepub fn render(&self, builder: CodeBuilder) -> CodeBuilder
pub fn render(&self, builder: CodeBuilder) -> CodeBuilder
Render the object literal to a CodeBuilder.